@@ -1,4 +1,4 @@
-# Copyright (C) 2014 - 2016  Jack O. Wasey
+# Copyright (C) 2014 - 2017  Jack O. Wasey
 #
 # This file is part of icd.
 #
@@ -40,7 +40,7 @@ simple_pts <- data.frame(
 
 simple_poa_pts <- data.frame(
   visit_id = c("v1", "v2", "v3", "v4"),
-  code = c("39891", "39790", "41791", "4401"), # deprecated tests likely need icd9 here
+  code = c("39891", "39790", "41791", "4401"),
   poa = c("y", "N", "E", NA_character_), # should tolerate mixed case
   stringsAsFactors = FALSE
 )
@@ -84,8 +84,8 @@ test_twenty <- structure(
 icd9(
   unlist(
     unname(
-      c(lapply(icd::icd9_map_ahrq, head, n = 1),
-        lapply(icd::icd9_map_ahrq, tail, n = 1)
+      c(lapply(icd9_map_ahrq, head, n = 1),
+        lapply(icd9_map_ahrq, tail, n = 1)
       )
     )
   )
@@ -99,24 +99,24 @@ ahrq_test_dat <- as.icd_long_data(
   )
 )
 
-elix_end_codes <- unlist(unname(c(lapply(icd::elixComorbid, head, n = 1),
-                                  lapply(icd::elixComorbid, tail, n = 1))))
+elix_end_codes <- unlist(unname(c(lapply(icd9_map_elix, head, n = 1),
+                                  lapply(icd9_map_elix, tail, n = 1))))
 elix_test_dat <- data.frame(
   visit_id = rep("visit1", times = length(elix_end_codes)),
   icd9 = elix_end_codes,
   stringsAsFactors = FALSE
 )
 
-quan_elix_end_codes <- unlist(unname(c(lapply(icd::icd9_map_quan_elix, head, n = 1),
-                                       lapply(icd::icd9_map_quan_elix, tail, n = 1))))
+quan_elix_end_codes <- unlist(unname(c(lapply(icd9_map_quan_elix, head, n = 1),
+                                       lapply(icd9_map_quan_elix, tail, n = 1))))
 quan_elix_test_dat <- data.frame(
   visit_id = rep("visit1", times = length(quan_elix_end_codes)),
   icd9 = quan_elix_end_codes,
   stringsAsFactors = FALSE
 )
 
-quan_deyo_end_codes <- unlist(unname(c(lapply(icd::quanDeyoComorbid, head, n = 1),
-                                       lapply(icd::quanDeyoComorbid, tail, n = 1))))
+quan_deyo_end_codes <- unlist(unname(c(lapply(icd9_map_quan_deyo, head, n = 1),
+                                       lapply(icd9_map_quan_deyo, tail, n = 1))))
 quan_deyo_test_dat <- data.frame(
   visit_id = rep("visit1", times = length(quan_deyo_end_codes)),
   icd9 = quan_deyo_end_codes,
@@ -174,4 +174,4 @@ hcc_test_invalid <- icd_long_data(
   visit_name = c("1", "2", "3", "4", "4"),
   icd_name = c("20084", "174242", "aB30410", "41514", "95893"),
   date = as.Date(c("2011-01-01", "2011-01-02", "2011-01-03",
-    "2011-01-04", "2011-01-04")))
\ No newline at end of file
+    "2011-01-04", "2011-01-04")))
